Crate kcr_apps_kubeblocks_io

Crate kcr_apps_kubeblocks_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the apps.kubeblocks.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

apps.kubeblocks.io/v1

  • ClusterDefinition
  • Cluster
  • ComponentDefinition
  • Component
  • ComponentVersion
  • ServiceDescriptor
  • ShardingDefinition
  • SidecarDefinition

apps.kubeblocks.io/v1alpha1

  • BackupPolicyTemplate
  • ClusterDefinition
  • Cluster
  • ClusterVersion
  • ComponentClassDefinition
  • ComponentDefinition
  • ComponentResourceConstraint
  • Component
  • ComponentVersion
  • ConfigConstraint
  • Configuration
  • OpsDefinition
  • OpsRequest
  • ServiceDescriptor

apps.kubeblocks.io/v1beta1

  • ConfigConstraint

Modules

v1
v1alpha1
v1beta1