pub struct ComponentDefinitionRuntimeContainersReadinessProbeHttpGet {
pub host: Option<String>,
pub http_headers: Option<Vec<ComponentDefinitionRuntimeContainersReadinessProbeHttpGetHttpHeaders>>,
pub path: Option<String>,
pub port: IntOrString,
pub scheme: Option<String>,
}Expand description
HTTPGet specifies the http request to perform.
Fields
host: Option<String>Host name to connect to, defaults to the pod IP. You probably want to set “Host” in httpHeaders instead.
http_headers: Option<Vec<ComponentDefinitionRuntimeContainersReadinessProbeHttpGetHttpHeaders>>Custom headers to set in the request. HTTP allows repeated headers.
path: Option<String>Path to access on the HTTP server.
port: IntOrStringName or number of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
scheme: Option<String>Scheme to use for connecting to the host. Defaults to HTTP.