pub struct ComponentDefinitionRuntimeInitContainersLifecyclePreStop {
pub exec: Option<ComponentDefinitionRuntimeInitContainersLifecyclePreStopExec>,
pub http_get: Option<ComponentDefinitionRuntimeInitContainersLifecyclePreStopHttpGet>,
pub sleep: Option<ComponentDefinitionRuntimeInitContainersLifecyclePreStopSleep>,
pub tcp_socket: Option<ComponentDefinitionRuntimeInitContainersLifecyclePreStopTcpSocket>,
}Expand description
PreStop is called immediately before a container is terminated due to an API request or management event such as liveness/startup probe failure, preemption, resource contention, etc. The handler is not called if the container crashes or exits. The Pod’s termination grace period countdown begins before the PreStop hook is executed. Regardless of the outcome of the handler, the container will eventually terminate within the Pod’s termination grace period (unless delayed by finalizers). Other management of the container blocks until the hook completes or until the termination grace period is reached. More info: https://kubernetes.io/docs/concepts/containers/container-lifecycle-hooks/#container-hooks
Fields
exec: Option<ComponentDefinitionRuntimeInitContainersLifecyclePreStopExec>Exec specifies the action to take.
http_get: Option<ComponentDefinitionRuntimeInitContainersLifecyclePreStopHttpGet>HTTPGet specifies the http request to perform.
sleep: Option<ComponentDefinitionRuntimeInitContainersLifecyclePreStopSleep>Sleep represents the duration that the container should sleep before being terminated.
tcp_socket: Option<ComponentDefinitionRuntimeInitContainersLifecyclePreStopTcpSocket>Deprecated. TCPSocket is NOT supported as a LifecycleHandler and kept for the backward compatibility. There are no validation of this field and lifecycle hooks will fail in runtime when tcp handler is specified.